==> php-residence_0.2.4.tar.gz: php-residence/tabella.php <==
<html>
<header>
<title> Visualizza prenotazioni PHP-Residence </title>
</header>
<body bgcolor=#ffffff>

<?php

#################################################################################
#    PHP-RESIDENCE
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################

$pag = "tabella.php";

include ("dati/connessione_db.php");
include ("includes/funzioni.php");
$tablenometariffe = ntariffe . $anno;
$tableprenota = prenota .$anno;
$tableperiodi = periodi . $anno;

$oggi = date("j/n/Y");
$ora = date("H:i");
echo "<font size=-2>".mex("situazione alle",$pag)." $ora ".mex("del",$pag)." $oggi</font><br>";

if ($anno_succ == "SI") { $mese = $mese + 12; }

$data_inizio_periodi = pg_exec("select * from $tableperiodi where idperiodi = 1");
$data_inizio_periodi = pg_result($data_inizio_periodi,0,datainizio);
$data_inizio_periodi = explode("-",$data_inizio_periodi);
$mese_inizio_periodi = $data_inizio_periodi[1];
if ($mese < $mese_inizio_periodi) { $mese = $mese_inizio_periodi; }
$data_fine_periodi = pg_exec("select max(idperiodi) from $tableperiodi");
$data_fine_periodi = pg_result($data_fine_periodi,0,max);
$data_fine_periodi = pg_exec("select * from $tableperiodi where idperiodi = $data_fine_periodi");
$data_fine_periodi = pg_result($data_fine_periodi,0,datainizio);
$data_fine_periodi = explode("-",$data_fine_periodi);
$mese_fine_periodi = $data_fine_periodi[1] + (($data_fine_periodi[2] - $anno) * 12);
if ($mese > $mese_fine_periodi) { $mese = $mese_fine_periodi; }

if ($mese == 25) {
$mese_mostra = 1;
$anno_mostra = $anno + 2;
} # fine if ($mese == 25)
else {
if ($mese > 12) {
$mese_mostra = $mese - 12;
$anno_mostra = $anno + 1;
} # fine if ($mese > 12)
else {
$mese_mostra = $mese;
$anno_mostra = $anno;
} # fine else if ($mese > 12)
} # fine else if ($mese == 25)

$tipo_periodi = pg_exec("select * from anni where idanni = $anno");
$tipo_periodi = pg_result($tipo_periodi,0,tipo_periodi);
$cellpadding = 5;
$cellspacing = 2;
if ($tipo_periodi == "g") {
$cellpadding = 3;
$cellspacing = 1;
} # fine if ($tipo_periodi == "g")
$aggiunta_tronca = pg_exec("select valpersonalizza_num from personalizza where idpersonalizza = 'aggiunta_tronca_nomi_tab1'");
$aggiunta_tronca = pg_result($aggiunta_tronca,0,valpersonalizza_num);
if ($tipo_periodi == "g" and $aggiunta_tronca < -2) $aggiunta_tronca = -2;

echo "<center><font size=+2><b>".mex("Tabella prenotazioni del",$pag)." $mese_mostra-$anno_mostra.</b></font></center>
<table border=3 cellspacing=$cellspacing cellpadding=$cellpadding align=\"center\" bgcolor=\"#b9ccd4\">";
if ($mese != 1 and $tipo_periodi != "g") { $mese_inizio_tab = $mese - 1; }
else { $mese_inizio_tab = $mese; }
$data_inizio_tab = date("M d, Y" , mktime(0,0,0,$mese_inizio_tab,1,$anno));
$data_inizio_tab = pg_exec("select * from $tableperiodi where datainizio >= '$data_inizio_tab' order by idperiodi");
$id_data_inizio_tab = pg_result($data_inizio_tab,0,idperiodi);
if ($mese != $mese_inizio_periodi and $mese != ($mese_inizio_periodi + 1)) {
$id_data_inizio_tab = $id_data_inizio_tab - 1;
} # fine if ($mese != $mese_inizio_periodi and $mese != ($mese_inizio_periodi + 1))
if ($mese != 25 and $tipo_periodi != "g") { $mese_fine_tab = $mese + 1; }
else {$mese_fine_tab = $mese; }
$data_fine_tab = date("M d, Y" , mktime(0,0,0,$mese_fine_tab,31,$anno));
$data_fine_tab = pg_exec("select * from $tableperiodi where datainizio <= '$data_fine_tab' order by idperiodi");
$num_date = pg_numrows($data_fine_tab);
$num_date = $num_date - 1;
$id_data_fine_tab = pg_result($data_fine_tab,$num_date,idperiodi);
$g_fine_tab = pg_result($data_fine_tab,$num_date,datafine);
$g_fine_tab = explode("-",$g_fine_tab);
$g_fine_tab = $g_fine_tab[0];
if ($g_fine_tab == 8) { $id_data_fine_tab = $id_data_fine_tab - 1; }
if ($tipo_periodi == "g" and $g_fine_tab > 1) $id_data_fine_tab = $id_data_fine_tab - $g_fine_tab + 1;
$num_colonne = $id_data_fine_tab - $id_data_inizio_tab + 1;
$appartamenti = pg_exec("select * from appartamenti order by idappartamenti");
$num_appartamenti = pg_numrows($appartamenti);

# controllo se vi sono prenotazioni in appartamenti cancellati
$num_appartamenti_cancellati = 0;
$query_prenota_app_canc = "select * from $tableprenota where iddatainizio <= $id_data_fine_tab and iddatafine >= $id_data_inizio_tab";
for ($num1 = 0 ; $num1 < $num_appartamenti ; $num1 = $num1 + 1) {
$id_appartamento = pg_result($appartamenti,$num1,idappartamenti);
$query_prenota_app_canc .= " and idappartamenti != '$id_appartamento'";
} # fine for $num1
$prenota_app_canc = pg_exec($query_prenota_app_canc);
$num_prenota_app_canc = pg_numrows($prenota_app_canc);
$num_app_canc = 0;
for ($num1 = 0 ; $num1 < $num_prenota_app_canc; $num1 = $num1 + 1) {
$idapp_prenota_app_canc = pg_result($prenota_app_canc,$num1,idappartamenti);
if ($app_canc_trovato[$idapp_prenota_app_canc] != "SI") {
$app_canc_trovato[$idapp_prenota_app_canc] = "SI";
$app_canc[$num_app_canc] = $idapp_prenota_app_canc;
$num_app_canc++;
} # fine if ($app_canc_trovato[$idapp_prenota_app_canc] != "SI")
} # fine for $num1

echo "<tr><td>&nbsp;</td>";
for ($num1 = 0 ; $num1 < $num_colonne ; $num1 = $num1 + 1) {
$id_settimana = $id_data_inizio_tab + $num1;
$riga_setimana = pg_exec("select * from $tableperiodi where idperiodi = $id_settimana");
$inizio_settimana = pg_result($riga_setimana,0,datainizio);
$inizio_settimana = explode("-",$inizio_settimana);
$g_inizio_settimana = $inizio_settimana[0];
$m_inizio_settimana = $inizio_settimana[1];
$fine_settimana = pg_result($riga_setimana,0,datafine);
$fine_settimana = explode("-",$fine_settimana);
$g_fine_settimana = $fine_settimana[0];
$m_fine_settimana = $fine_settimana[1];
$d_inizio_settimana = "$g_inizio_settimana-$m_inizio_settimana";
if ($tipo_periodi == "g") {
$d_inizio_settimana = $g_inizio_settimana;
$a_inizio_settimana = $inizio_settimana[2];
$domenica = date("D" , mktime(0,0,0,$m_inizio_settimana,$g_inizio_settimana,$a_inizio_settimana));
if ($domenica == "Sun") $d_inizio_settimana = "<font color=\"red\"><b>".$g_inizio_settimana."</b></font>";
} # fine if ($tipo_periodi == "g")
$d_fine_settimana = "$g_fine_settimana-$m_fine_settimana";
if ($tipo_periodi == "g") {
$d_fine_settimana = $g_fine_settimana;
#$a_fine_settimana = $fine_settimana[2];
#$domenica = date("D" , mktime(0,0,0,$m_fine_settimana,$g_fine_settimana,$a_fine_settimana));
#if ($domenica == "Sun") $d_fine_settimana = "<font color=\"red\"><b>".$g_fine_settimana."</b></font>";
} # fine if ($tipo_periodi == "g")
echo "<td align=\"center\"";
if ($m_inizio_settimana == $mese_mostra or $m_fine_settimana == $mese_mostra) { echo " bgcolor =\"#DAEDFF\""; }
echo ">$d_inizio_settimana<br>---<br>$d_fine_settimana</td>";
} # fine for $num1
echo "</tr>";

for ($num1 = 0 ; $num1 < ($num_appartamenti + $num_app_canc) ; $num1 = $num1 + 1) {
if ($num1 < $num_appartamenti) {
$id_appartamento = pg_result($appartamenti,$num1,idappartamenti);
echo "<tr><td>";
if (strlen($id_appartamento) > 2) echo "<font size=-2>";
echo "$id_appartamento";
if (strlen($id_appartamento) > 2) echo "</font>";
echo "</td>";
} # fine if ($num1 < $num_appartamenti)
else {
$id_appartamento = $app_canc[($num1 - $num_appartamenti)];
echo "<tr><td>";
if (strlen($id_appartamento) > 2) echo "<font size=-2>";
echo "<font color=\"red\">$id_appartamento</font>";
if (strlen($id_appartamento) > 2) echo "</font>";
echo "</td>";
} # fine else if ($num1 < $num_appartamenti)

for ($num2 = 0 ; $num2 < $num_colonne ; $num2 = $num2 + 1) {
$id_settimana = $id_data_inizio_tab + $num2;
$prenotazione_presente = pg_exec("select * from $tableprenota where idappartamenti = '$id_appartamento' and iddatainizio <= $id_settimana and iddatafine >= $id_settimana");
$esiste = pg_numrows($prenotazione_presente);
if ($esiste == 1) {
$id_prenota = pg_result($prenotazione_presente,0,idprenota);
$id_clienti = pg_result($prenotazione_presente,0,idclienti);
$cognome = pg_exec("select * from clienti where idclienti = $id_clienti");
$cognome = pg_result($cognome,0,cognome);

$colore = "";
$pagato = pg_result($prenotazione_presente,0,pagato);
$confermato = pg_result($prenotazione_presente,0,conferma);
$confermato = substr($confermato,0,1);
if (!$pagato) { $pagato = 0; }
$caparra = pg_result($prenotazione_presente,0,caparra);
if (!$caparra) { $caparra = 0; }
$costo_tot = pg_result($prenotazione_presente,0,tariffa_tot);
$colore = "#99ccd4"; #celeste
if ($pagato < $costo_tot) {
$colore = "#FFEE22"; #giallo
if ($pagato < $caparra) $colore = "#FF9900"; #arancione
if ($confermato != "S") $colore = "#CC0000"; # rosso
} # fine if ($pagato < $costo_tot)

$id_inizio_prenota = pg_result($prenotazione_presente,0,iddatainizio);
$id_fine_prenota = pg_result($prenotazione_presente,0,iddatafine);
if ($id_inizio_prenota > $id_data_inizio_tab) { $id_inizio = $id_inizio_prenota; }
else { $id_inizio = $id_data_inizio_tab; }
if ($id_fine_prenota < $id_data_fine_tab) { $id_fine = $id_fine_prenota; }
else { $id_fine = $id_data_fine_tab; }
$colonne = $id_fine - $id_inizio + 1;
if ($colonne > 1) {
$prenotazioni_presenti = pg_exec("select * from $tableprenota where idappartamenti = '$id_appartamento' and iddatainizio <= $id_fine_prenota and iddatafine >= $id_inizio_prenota");
$esiste = pg_numrows($prenotazioni_presenti);
if ($esiste > 1) $cognome = mex("ERRORE",$pag);
} # fine if ($colonne > 1)
$riduci_font = "";
$lung_cognome = strlen($cognome);
$lung_freccia = 0;
if ($id_fine_prenota > $id_data_fine_tab or $id_inizio_prenota < $id_data_inizio_tab) $lung_freccia = 3;
$lung_non_ridotta = (7+$aggiunta_tronca)*$colonne - $lung_freccia;
if ($tipo_periodi == "g") $lung_non_ridotta = (3+$aggiunta_tronca)*$colonne - $lung_freccia;
if ($lung_cognome > $lung_non_ridotta) $riduci_font = "SI";
$lung_non_tronca = (9+$aggiunta_tronca)*$colonne;
if ($tipo_periodi == "g") $lung_non_tronca = (5+$aggiunta_tronca)*$colonne;
if ($lung_freccia == 3) $lung_non_tronca = $lung_non_tronca - 1;
if ($lung_cognome > ($lung_non_tronca+1)) $cognome = substr($cognome,0,$lung_non_tronca).".";
echo "<td";
if ($colore) { echo " bgcolor =\"$colore\""; }
echo" align=\"center\" colspan=\"$colonne\">";
if ($riduci_font) echo "<font size=-2>";
if ($id_inizio_prenota < $id_data_inizio_tab) { echo "<- "; }
echo "<a href=\"modifica_prenota.php?id_prenota=$id_prenota&anno=$anno&mese=$mese\">$cognome</a>";
if ($id_fine_prenota > $id_data_fine_tab) { echo " ->"; }
if ($riduci_font) echo "</font>";
echo "</td>";
$num2 = $num2 + $colonne - 1;
} # fine if ($esiste == 1)
else {
if ($esiste == 0) echo "<td>&nbsp;</td>";
else echo "<td>".mex("ERRORE",$pag)."</td>";
} # fine else if ($esiste == 1)
} # fine for $num2

echo "</tr>";
} # fine for $num1

echo "</table><center>
<form method=\"post\" action=\"inizio.php\">";
if ($mese != 1) {
if ($tipo_periodi == "g") $mese_inizio_tab--; 
echo "<a href=\"tabella.php?anno=$anno&mese=$mese_inizio_tab\"><--</a>&nbsp;&nbsp;&nbsp;&nbsp;";
} # fine if ($mese != 1)
echo "<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"submit\" name=\"torna\" value=\"".mex("Torna al men principale",$pag)."\">";
if ($mese != 25) {
if ($tipo_periodi == "g") $mese_fine_tab++; 
echo "&nbsp;&nbsp;&nbsp;&nbsp;<a href=\"tabella.php?anno=$anno&mese=$mese_fine_tab\">--></a>";
} # fine if ($mese != 25)
if ($tipo_periodi == "g") {
echo "</form>
<form method=\"post\" action=\"tabella3.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"hidden\" name=\"mese\" value=\"$mese\">
<input type=\"submit\" name=\"tab3\" value=\"".mex("Visualizza la tabella per la stampa",$pag)."\">
</form></center>";
} # fine if ($tipo_periodi == "g")
else {
echo "</form>
<form method=\"post\" action=\"tabella2.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"hidden\" name=\"mese\" value=\"$mese\">
<input type=\"submit\" name=\"tab2\" value=\"".mex("Visualizza la tabella con i giorni",$pag)."\">
</form></center>";
} # fine else if ($tipo_periodi == "g")



?>

</body>
</html>

==> php-residence_0.3.tar.gz: php-residence/tabella.php <==
<html>
<header>
<title> Visualizza prenotazioni PHP-Residence </title>
</header>
<body bgcolor=#ffffff>

<?php

#################################################################################
#    PHP-RESIDENCE
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################

$pag = "tabella.php";

include("./dati/dati_connessione.php");
include("./includes/funzioni_$PHPR_DB_TYPE.php");
connetti_db($PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT);
include ("./includes/funzioni.php");
$tablenometariffe = ntariffe . $anno;
$tableprenota = prenota .$anno;
$tableperiodi = periodi . $anno;

#$tabelle_lock = array("$tableprenota");
$altre_tab_lock = array("$tableprenota","$tableperiodi","appartamenti","clienti");
$tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);

$oggi = date("j/n/Y");
$ora = date("H:i");
echo "<font size=-2>".mex("situazione alle",$pag)." $ora ".mex("del",$pag)." $oggi</font><br>";

if ($anno_succ == "SI") { $mese = $mese + 12; }

$data_inizio_periodi = esegui_query("select * from $tableperiodi where idperiodi = 1");
$data_inizio_periodi = risul_query($data_inizio_periodi,0,datainizio);
$data_inizio_periodi = explode("-",$data_inizio_periodi);
$mese_inizio_periodi = $data_inizio_periodi[1];
if ($mese < $mese_inizio_periodi) { $mese = $mese_inizio_periodi; }
$data_fine_periodi = esegui_query("select max(idperiodi) from $tableperiodi");
$data_fine_periodi = risul_query($data_fine_periodi,0,0);
$data_fine_periodi = esegui_query("select * from $tableperiodi where idperiodi = $data_fine_periodi");
$data_fine_periodi = risul_query($data_fine_periodi,0,datainizio);
$data_fine_periodi = explode("-",$data_fine_periodi);
$mese_fine_periodi = $data_fine_periodi[1] + (($data_fine_periodi[0] - $anno) * 12);
if ($mese > $mese_fine_periodi) { $mese = $mese_fine_periodi; }

if ($mese == 25) {
$mese_mostra = 1;
$anno_mostra = $anno + 2;
} # fine if ($mese == 25)
else {
if ($mese > 12) {
$mese_mostra = $mese - 12;
$anno_mostra = $anno + 1;
} # fine if ($mese > 12)
else {
$mese_mostra = $mese;
$anno_mostra = $anno;
} # fine else if ($mese > 12)
} # fine else if ($mese == 25)

$tipo_periodi = esegui_query("select * from anni where idanni = $anno");
$tipo_periodi = risul_query($tipo_periodi,0,tipo_periodi);
$cellpadding = 5;
$cellspacing = 2;
if ($tipo_periodi == "g") {
$cellpadding = 3;
$cellspacing = 1;
} # fine if ($tipo_periodi == "g")
$aggiunta_tronca = esegui_query("select valpersonalizza_num from personalizza where idpersonalizza = 'aggiunta_tronca_nomi_tab1'");
$aggiunta_tronca = risul_query($aggiunta_tronca,0,valpersonalizza_num);
if ($tipo_periodi == "g" and $aggiunta_tronca < -2) $aggiunta_tronca = -2;

echo "<center><font size=+2><b>".mex("Tabella prenotazioni del",$pag)." $mese_mostra-$anno_mostra.</b></font></center>
<table border=3 cellspacing=$cellspacing cellpadding=$cellpadding align=\"center\" bgcolor=\"#b9ccd4\">";
if ($mese != 1 and $tipo_periodi != "g") { $mese_inizio_tab = $mese - 1; }
else { $mese_inizio_tab = $mese; }
$data_inizio_tab = date("Y-m-d" , mktime(0,0,0,$mese_inizio_tab,1,$anno));
$data_inizio_tab = esegui_query("select * from $tableperiodi where datainizio >= '$data_inizio_tab' order by idperiodi");
$id_data_inizio_tab = risul_query($data_inizio_tab,0,idperiodi);
if ($mese != $mese_inizio_periodi and $mese != ($mese_inizio_periodi + 1)) {
$id_data_inizio_tab = $id_data_inizio_tab - 1;
} # fine if ($mese != $mese_inizio_periodi and $mese != ($mese_inizio_periodi + 1))
if ($mese != 25 and $tipo_periodi != "g") { $mese_fine_tab = $mese + 1; }
else {$mese_fine_tab = $mese; }
$data_fine_tab = date("Y-m-d" , mktime(0,0,0,$mese_fine_tab,31,$anno));
$data_fine_tab = esegui_query("select * from $tableperiodi where datainizio <= '$data_fine_tab' order by idperiodi");
$num_date = numlin_query($data_fine_tab);
$num_date = $num_date - 1;
$id_data_fine_tab = risul_query($data_fine_tab,$num_date,idperiodi);
$g_fine_tab = risul_query($data_fine_tab,$num_date,datafine);
$g_fine_tab = explode("-",$g_fine_tab);
$g_fine_tab = $g_fine_tab[2];
if ($g_fine_tab == 8) { $id_data_fine_tab = $id_data_fine_tab - 1; }
if ($tipo_periodi == "g" and $g_fine_tab > 1) $id_data_fine_tab = $id_data_fine_tab - $g_fine_tab + 1;
$num_colonne = $id_data_fine_tab - $id_data_inizio_tab + 1;
$appartamenti = esegui_query("select * from appartamenti order by idappartamenti");
$num_appartamenti = numlin_query($appartamenti);

# controllo se vi sono prenotazioni in appartamenti cancellati
$num_appartamenti_cancellati = 0;
$query_prenota_app_canc = "select * from $tableprenota where iddatainizio <= $id_data_fine_tab and iddatafine >= $id_data_inizio_tab";
for ($num1 = 0 ; $num1 < $num_appartamenti ; $num1 = $num1 + 1) {
$id_appartamento = risul_query($appartamenti,$num1,idappartamenti);
$query_prenota_app_canc .= " and idappartamenti != '$id_appartamento'";
} # fine for $num1
$prenota_app_canc = esegui_query($query_prenota_app_canc);
$num_prenota_app_canc = numlin_query($prenota_app_canc);
$num_app_canc = 0;
for ($num1 = 0 ; $num1 < $num_prenota_app_canc; $num1 = $num1 + 1) {
$idapp_prenota_app_canc = risul_query($prenota_app_canc,$num1,idappartamenti);
if ($app_canc_trovato[$idapp_prenota_app_canc] != "SI") {
$app_canc_trovato[$idapp_prenota_app_canc] = "SI";
$app_canc[$num_app_canc] = $idapp_prenota_app_canc;
$num_app_canc++;
} # fine if ($app_canc_trovato[$idapp_prenota_app_canc] != "SI")
} # fine for $num1

echo "<tr><td>&nbsp;</td>";
for ($num1 = 0 ; $num1 < $num_colonne ; $num1 = $num1 + 1) {
$id_settimana = $id_data_inizio_tab + $num1;
$riga_setimana = esegui_query("select * from $tableperiodi where idperiodi = $id_settimana");
$inizio_settimana = risul_query($riga_setimana,0,datainizio);
$inizio_settimana = explode("-",$inizio_settimana);
$g_inizio_settimana = $inizio_settimana[2];
$m_inizio_settimana = $inizio_settimana[1];
$fine_settimana = risul_query($riga_setimana,0,datafine);
$fine_settimana = explode("-",$fine_settimana);
$g_fine_settimana = $fine_settimana[2];
$m_fine_settimana = $fine_settimana[1];
$d_inizio_settimana = "$g_inizio_settimana-$m_inizio_settimana";
if ($tipo_periodi == "g") {
$d_inizio_settimana = $g_inizio_settimana;
$a_inizio_settimana = $inizio_settimana[0];
$domenica = date("D" , mktime(0,0,0,$m_inizio_settimana,$g_inizio_settimana,$a_inizio_settimana));
if ($domenica == "Sun") $d_inizio_settimana = "<font color=\"red\"><b>".$g_inizio_settimana."</b></font>";
} # fine if ($tipo_periodi == "g")
$d_fine_settimana = "$g_fine_settimana-$m_fine_settimana";
if ($tipo_periodi == "g") {
$d_fine_settimana = $g_fine_settimana;
#$a_fine_settimana = $fine_settimana[2];
#$domenica = date("D" , mktime(0,0,0,$m_fine_settimana,$g_fine_settimana,$a_fine_settimana));
#if ($domenica == "Sun") $d_fine_settimana = "<font color=\"red\"><b>".$g_fine_settimana."</b></font>";
} # fine if ($tipo_periodi == "g")
echo "<td align=\"center\"";
if ($m_inizio_settimana == $mese_mostra or $m_fine_settimana == $mese_mostra) { echo " bgcolor =\"#DAEDFF\""; }
echo ">$d_inizio_settimana<br>---<br>$d_fine_settimana</td>";
} # fine for $num1
echo "</tr>";

for ($num1 = 0 ; $num1 < ($num_appartamenti + $num_app_canc) ; $num1 = $num1 + 1) {
if ($num1 < $num_appartamenti) {
$id_appartamento = risul_query($appartamenti,$num1,idappartamenti);
echo "<tr><td>";
if (strlen($id_appartamento) > 2) echo "<font size=-2>";
echo "$id_appartamento";
if (strlen($id_appartamento) > 2) echo "</font>";
echo "</td>";
} # fine if ($num1 < $num_appartamenti)
else {
$id_appartamento = $app_canc[($num1 - $num_appartamenti)];
echo "<tr><td>";
if (strlen($id_appartamento) > 2) echo "<font size=-2>";
echo "<font color=\"red\">$id_appartamento</font>";
if (strlen($id_appartamento) > 2) echo "</font>";
echo "</td>";
} # fine else if ($num1 < $num_appartamenti)

for ($num2 = 0 ; $num2 < $num_colonne ; $num2 = $num2 + 1) {
$id_settimana = $id_data_inizio_tab + $num2;
$prenotazione_presente = esegui_query("select * from $tableprenota where idappartamenti = '$id_appartamento' and iddatainizio <= $id_settimana and iddatafine >= $id_settimana");
$esiste = numlin_query($prenotazione_presente);
if ($esiste == 1) {
$id_prenota = risul_query($prenotazione_presente,0,idprenota);
$id_clienti = risul_query($prenotazione_presente,0,idclienti);
$cognome = esegui_query("select * from clienti where idclienti = $id_clienti");
$cognome = risul_query($cognome,0,cognome);

$colore = "";
$pagato = risul_query($prenotazione_presente,0,pagato);
$confermato = risul_query($prenotazione_presente,0,conferma);
$confermato = substr($confermato,0,1);
if (!$pagato) { $pagato = 0; }
$caparra = risul_query($prenotazione_presente,0,caparra);
if (!$caparra) { $caparra = 0; }
$costo_tot = risul_query($prenotazione_presente,0,tariffa_tot);
$colore = "#99ccd4"; #celeste
if ($pagato < $costo_tot) {
$colore = "#FFEE22"; #giallo
if ($pagato < $caparra) $colore = "#FF9900"; #arancione
if ($confermato != "S") $colore = "#CC0000"; # rosso
} # fine if ($pagato < $costo_tot)

$id_inizio_prenota = risul_query($prenotazione_presente,0,iddatainizio);
$id_fine_prenota = risul_query($prenotazione_presente,0,iddatafine);
if ($id_inizio_prenota > $id_data_inizio_tab) { $id_inizio = $id_inizio_prenota; }
else { $id_inizio = $id_data_inizio_tab; }
if ($id_fine_prenota < $id_data_fine_tab) { $id_fine = $id_fine_prenota; }
else { $id_fine = $id_data_fine_tab; }
$colonne = $id_fine - $id_inizio + 1;
if ($colonne > 1) {
$prenotazioni_presenti = esegui_query("select * from $tableprenota where idappartamenti = '$id_appartamento' and iddatainizio <= $id_fine_prenota and iddatafine >= $id_inizio_prenota");
$esiste = numlin_query($prenotazioni_presenti);
if ($esiste > 1) $cognome = mex("ERRORE",$pag);
} # fine if ($colonne > 1)
$riduci_font = "";
$lung_cognome = strlen($cognome);
$lung_freccia = 0;
if ($id_fine_prenota > $id_data_fine_tab or $id_inizio_prenota < $id_data_inizio_tab) $lung_freccia = 3;
$lung_non_ridotta = (7+$aggiunta_tronca)*$colonne - $lung_freccia;
if ($tipo_periodi == "g") $lung_non_ridotta = (3+$aggiunta_tronca)*$colonne - $lung_freccia;
if ($lung_cognome > $lung_non_ridotta) $riduci_font = "SI";
$lung_non_tronca = (9+$aggiunta_tronca)*$colonne;
if ($tipo_periodi == "g") $lung_non_tronca = (5+$aggiunta_tronca)*$colonne;
if ($lung_freccia == 3) $lung_non_tronca = $lung_non_tronca - 1;
if ($lung_cognome > ($lung_non_tronca+1)) $cognome = substr($cognome,0,$lung_non_tronca).".";
echo "<td";
if ($colore) { echo " bgcolor =\"$colore\""; }
echo" align=\"center\" colspan=\"$colonne\">";
if ($riduci_font) echo "<font size=-2>";
if ($id_inizio_prenota < $id_data_inizio_tab) { echo "<- "; }
echo "<a href=\"modifica_prenota.php?id_prenota=$id_prenota&anno=$anno&mese=$mese\">$cognome</a>";
if ($id_fine_prenota > $id_data_fine_tab) { echo " ->"; }
if ($riduci_font) echo "</font>";
echo "</td>";
$num2 = $num2 + $colonne - 1;
} # fine if ($esiste == 1)
else {
if ($esiste == 0) echo "<td>&nbsp;</td>";
else echo "<td>".mex("ERRORE",$pag)."</td>";
} # fine else if ($esiste == 1)
} # fine for $num2

echo "</tr>";
} # fine for $num1

unlock_tabelle($tabelle_lock);

echo "</table><center>
<form method=\"post\" action=\"inizio.php\">";
if ($mese != 1) {
if ($tipo_periodi == "g") $mese_inizio_tab--; 
echo "<a href=\"tabella.php?anno=$anno&mese=$mese_inizio_tab\"><--</a>&nbsp;&nbsp;&nbsp;&nbsp;";
} # fine if ($mese != 1)
echo "<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"submit\" name=\"torna\" value=\"".mex("Torna al men principale",$pag)."\">";
if ($mese != 25) {
if ($tipo_periodi == "g") $mese_fine_tab++; 
echo "&nbsp;&nbsp;&nbsp;&nbsp;<a href=\"tabella.php?anno=$anno&mese=$mese_fine_tab\">--></a>";
} # fine if ($mese != 25)
if ($tipo_periodi == "g") {
echo "</form>
<form method=\"post\" action=\"tabella3.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"hidden\" name=\"mese\" value=\"$mese\">
<input type=\"submit\" name=\"tab3\" value=\"".mex("Visualizza la tabella per la stampa",$pag)."\">
</form></center>";
} # fine if ($tipo_periodi == "g")
else {
echo "</form>
<form method=\"post\" action=\"tabella2.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"hidden\" name=\"mese\" value=\"$mese\">
<input type=\"submit\" name=\"tab2\" value=\"".mex("Visualizza la tabella con i giorni",$pag)."\">
</form></center>";
} # fine else if ($tipo_periodi == "g")



?>

</body>
</html>
